package com.benyun.project.third.area.mapper;

import com.benyun.project.third.area.domain.OmsArea;

import java.util.List;

/**
 * 行政区划数据Mapper接口
 *
 * @author benyun
 * @date 2023-12-14
 */
public interface OmsAreaMapper
{
    /**
     * 查询行政区划数据
     *
     * @param id 行政区划数据主键
     * @return 行政区划数据
     */
    public OmsArea selectOmsAreaById(String id);

    public OmsArea selectOmsAreaByExtName(String extName);


    /**
     * 通过地名模糊查询
     * @param provinceName
     * @return
     */
    OmsArea selectOmsAreaByExtNameFuzzy(String extName);

    /**
     * 查询行政区划数据列表
     *
     * @param omsArea 行政区划数据
     * @return 行政区划数据集合
     */
    public List<OmsArea> selectOmsAreaList(OmsArea omsArea);

    /**
     * 新增行政区划数据
     *
     * @param omsArea 行政区划数据
     * @return 结果
     */
    public int insertOmsArea(OmsArea omsArea);

    /**
     * 修改行政区划数据
     *
     * @param omsArea 行政区划数据
     * @return 结果
     */
    public int updateOmsArea(OmsArea omsArea);

    /**
     * 删除行政区划数据
     *
     * @param id 行政区划数据主键
     * @return 结果
     */
    public int deleteOmsAreaById(String id);

    /**
     * 批量删除行政区划数据
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOmsAreaByIds(String[] ids);

    OmsArea selectOmsAreaByExtNameAndPid(String extName, String pid);
}
